@@ -95,27 +95,27 @@ class Embeddings:
         with tempfile.NamedTemporaryFile(mode="wb", suffix=".npy") as buffer:
             # Load documents into database and transform to vectors
             ids, dimensions, embeddings = transform(documents, buffer)
+            if ids:
+                # Build LSA model (if enabled). Remove principal components from embeddings.
+                if self.config.get("pca"):
+                    self.reducer = Reducer(embeddings, self.config["pca"])
+                    self.reducer(embeddings)
 
-            # Build LSA model (if enabled). Remove principal components from embeddings.
-            if self.config.get("pca"):
-                self.reducer = Reducer(embeddings, self.config["pca"])
-                self.reducer(embeddings)
+                # Normalize embeddings
+                self.normalize(embeddings)
 
-            # Normalize embeddings
-            self.normalize(embeddings)
+                # Save index dimensions
+                self.config["dimensions"] = dimensions
 
-            # Save index dimensions
-            self.config["dimensions"] = dimensions
+                # Create approximate nearest neighbor index
+                self.ann = ANNFactory.create(self.config)
 
-            # Create approximate nearest neighbor index
-            self.ann = ANNFactory.create(self.config)
+                # Add embeddings to the index
+                self.ann.index(embeddings)
 
-            # Add embeddings to the index
-            self.ann.index(embeddings)
-
-            # Save indexids-ids mapping for indexes with no database, except when this is a reindex action
-            if not reindex and not self.database:
-                self.config["ids"] = ids
+                # Save indexids-ids mapping for indexes with no database, except when this is a reindex action
+                if not reindex and not self.database:
+                    self.config["ids"] = ids
 
     def upsert(self, documents):
         """
@@ -138,16 +138,16 @@ class Embeddings:
         with tempfile.NamedTemporaryFile(mode="wb", suffix=".npy") as buffer:
             # Load documents into database and transform to vectors
             ids, _, embeddings = transform(documents, buffer)
+            if ids:
+                # Normalize embeddings
+                self.normalize(embeddings)
 
-            # Normalize embeddings
-            self.normalize(embeddings)
+                # Append embeddings to the index
+                self.ann.append(embeddings)
 
-            # Append embeddings to the index
-            self.ann.append(embeddings)
-
-            # Save indexids-ids mapping for indexes with no database
-            if not self.database:
-                self.config["ids"] = self.config["ids"] + ids
+                # Save indexids-ids mapping for indexes with no database
+                if not self.database:
+                    self.config["ids"] = self.config["ids"] + ids
 
     def delete(self, ids):
         """
@@ -340,18 +340,38 @@ class Embeddings:
         # Add index and sort desc based on score
         return [sorted(enumerate(score), key=lambda x: x[1], reverse=True) for score in scores]
 
-    def load(self, path):
+    def exists(self, path, cloud=None):
+        """
+        Checks if an index exists at path.
+
+        Args:
+            path: input path
+            cloud: cloud storage configuration
+
+        Returns:
+            True if index exists, False otherwise
+        """
+
+        # Check if this is an archive file and exists
+        path, apath = self.checkarchive(path)
+        if apath:
+            return self.archive.exists(apath, cloud)
+
+        return os.path.exists(f"{path}/config") and os.path.exists(f"{path}/embeddings")
+
+    def load(self, path, cloud=None):
         """
         Loads an existing index from path.
 
         Args:
             path: input path
+            cloud: cloud storage configuration
         """
 
         # Check if this is an archive file and extract
         path, apath = self.checkarchive(path)
         if apath:
-            self.archive.load(apath)
+            self.archive.load(apath, cloud)
 
         # Index configuration
         with open(f"{path}/config", "rb") as handle:
@@ -383,25 +403,13 @@ class Embeddings:
         if self.database:
             self.database.load(f"{path}/documents")
 
-    def exists(self, path):
-        """
-        Checks if an index exists at path.
-
-        Args:
-            path: input path
-
-        Returns:
-            True if index exists, False otherwise
-        """
-
-        return os.path.exists(f"{path}/config") and os.path.exists(f"{path}/embeddings")
-
-    def save(self, path):
+    def save(self, path, cloud=None):
         """
         Saves an index.
 
         Args:
             path: output path
+            cloud: cloud storage configuration
         """
 
         if self.config:
@@ -438,7 +446,7 @@ class Embeddings:
 
             # If this is an archive, save it
             if apath:
-                self.archive.save(apath)
+                self.archive.save(apath, cloud)
 
     def close(self):
         """
