@@ -2,6 +2,7 @@
 Transformers module
 """
 
+import os
 import pickle
 import tempfile
 
@@ -14,9 +15,8 @@ except ImportError:
     SENTENCE_TRANSFORMERS = False
 
 from .base import Vectors
-from ..models import Models
-from ..pipeline.tokenizer import Tokenizer
-from .pooling import MeanPooling
+from ..models import MeanPooling, Models, Pooling
+from ..pipeline import Tokenizer
 
 
 class TransformersVectors(Vectors):
@@ -26,14 +26,18 @@ class TransformersVectors(Vectors):
 
     def load(self, path):
         # Flag that determines if transformers or sentence-transformers should be used to build embeddings
-        transformers = self.config.get("method") != "sentence-transformers"
+        method = self.config.get("method")
+        transformers = method != "sentence-transformers"
 
         # Tensor device id
         deviceid = Models.deviceid(self.config.get("gpu", True))
 
         # Build embeddings with transformers (default)
         if transformers:
-            return MeanPooling(path, device=deviceid)
+            if isinstance(path, bytes) or (isinstance(path, str) and os.path.isfile(path)) or method == "pooling":
+                return Pooling(path, device=deviceid, tokenizer=self.config.get("tokenizer"))
+
+            return MeanPooling(path, device=deviceid, tokenizer=self.config.get("tokenizer"))
 
         if not SENTENCE_TRANSFORMERS:
             raise ImportError('sentence-transformers is not available - install "similarity" extra to enable')
@@ -42,7 +46,7 @@ class TransformersVectors(Vectors):
         return SentenceTransformer(path, device=Models.reference(deviceid))
 
     def index(self, documents):
-        ids, dimensions, stream = [], None, None
+        ids, dimensions, batches, stream = [], None, 0, None
 
         # Convert all documents to embedding arrays, stream embeddings to disk to control memory usage
         with tempfile.NamedTemporaryFile(mode="wb", suffix=".npy", delete=False) as output:
@@ -55,6 +59,7 @@ class TransformersVectors(Vectors):
                     # Convert batch to embeddings
                     uids, dimensions = self.batch(batch, output)
                     ids.extend(uids)
+                    batches += 1
 
                     batch = []
 
@@ -62,12 +67,13 @@ class TransformersVectors(Vectors):
             if batch:
                 uids, dimensions = self.batch(batch, output)
                 ids.extend(uids)
+                batches += 1
 
-        return (ids, dimensions, stream)
+        return (ids, dimensions, batches, stream)
 
     def transform(self, document):
-        # Convert input document to text and build embeddings
-        return self.model.encode([self.text(document[1])])[0]
+        # Prepare input document for transformers model and build embeddings
+        return self.model.encode([self.prepare(document[1])])[0]
 
     def batch(self, documents, output):
         """
@@ -81,37 +87,37 @@ class TransformersVectors(Vectors):
             (ids, dimensions) list of ids and number of dimensions in embeddings
         """
 
-        # Extract ids and convert input documents to text
+        # Extract ids and prepare input documents for transformers model
         ids = [uid for uid, _, _ in documents]
-        documents = [self.text(text) for _, text, _ in documents]
+        documents = [self.prepare(data) for _, data, _ in documents]
         dimensions = None
 
         # Build embeddings
         embeddings = self.model.encode(documents)
-        for embedding in embeddings:
-            if not dimensions:
-                # Set number of dimensions for embeddings
-                dimensions = embedding.shape[0]
-
-            pickle.dump(embedding, output)
+        if embeddings is not None:
+            dimensions = embeddings.shape[1]
+            pickle.dump(embeddings, output, protocol=4)
 
         return (ids, dimensions)
 
-    def text(self, text):
+    def prepare(self, data):
         """
-        Converts input into text that can be processed by transformer models. This method supports
-        optional string tokenization and joins tokenized input into text.
+        Prepares input data for transformers model. This method supports optional string tokenization and
+        joins tokenized input into text.
 
         Args:
-            text: text|tokens
+            data: input data
+
+        Returns:
+            data formatted for transformers model
         """
 
         # Optional string tokenization
-        if self.tokenize and isinstance(text, str):
-            text = Tokenizer.tokenize(text)
+        if self.tokenize and isinstance(data, str):
+            data = Tokenizer.tokenize(data)
 
-        # Transformer models require string input
-        if isinstance(text, list):
-            text = " ".join(text)
+        # Convert token list to string
+        if isinstance(data, list):
+            data = " ".join(data)
 
-        return text
+        return data
