@@ -21,7 +21,7 @@ except ImportError:
     WORDS = False
 
 from .base import Vectors
-from ..pipeline.tokenizer import Tokenizer
+from ..pipeline import Tokenizer
 
 # Multiprocessing helper methods
 # pylint: disable=W0603
@@ -48,14 +48,12 @@ def transform(document):
     Multiprocessing helper method. Transforms document into an embeddings vector.
 
     Args:
-        document: (id, text|tokens, tags)
+        document: (id, data, tags)
 
     Returns:
         (id, embedding)
     """
 
-    global VECTORS
-
     return (document[0], VECTORS.transform(document))
 
 
@@ -118,9 +116,9 @@ class WordVectors(Vectors):
                         dimensions = embedding.shape[0]
 
                     ids.append(uid)
-                    pickle.dump(embedding, output)
+                    pickle.dump(embedding, output, protocol=4)
 
-        return (ids, dimensions, stream)
+        return (ids, dimensions, len(ids), stream)
 
     def transform(self, document):
         # Convert to tokens if necessary
@@ -153,6 +151,28 @@ class WordVectors(Vectors):
 
         return self.model.query(tokens)
 
+    @staticmethod
+    def isdatabase(path):
+        """
+        Checks if this is a SQLite database file which is the file format used for word vectors databases.
+
+        Args:
+            path: path to check
+
+        Returns:
+            True if this is a SQLite database
+        """
+
+        if isinstance(path, str) and os.path.isfile(path) and os.path.getsize(path) >= 100:
+            # Read 100 byte SQLite header
+            with open(path, "rb") as f:
+                header = f.read(100)
+
+            # Check for SQLite header
+            return header.startswith(b"SQLite format 3\000")
+
+        return False
+
     @staticmethod
     def build(data, size, mincount, path):
         """
@@ -169,12 +189,12 @@ class WordVectors(Vectors):
         model = fasttext.train_unsupervised(data, dim=size, minCount=mincount)
 
         # Output file path
-        print("Building %d dimension model" % size)
+        print(f"Building {size} dimension model")
 
         # Output vectors in vec/txt format
-        with open(path + ".txt", "w") as output:
+        with open(path + ".txt", "w", encoding="utf-8") as output:
             words = model.get_words()
-            output.write("%d %d\n" % (len(words), model.get_dimension()))
+            output.write(f"{len(words)} {model.get_dimension()}\n")
 
             for word in words:
                 # Skip end of line token
